@@ -17,13 +17,13 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_elb.paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
-from mypy_boto3_elb.waiter import (
+from .paginator import (
     AnyInstanceInServiceWaiter,
+    DescribeAccountLimitsPaginator,
+    DescribeLoadBalancersPaginator,
     InstanceDeregisteredWaiter,
     InstanceInServiceWaiter,
 )
-
 from .type_defs import (
     AddAvailabilityZonesOutputTypeDef,
     ApplySecurityGroupsToLoadBalancerOutputTypeDef,
@@ -96,7 +96,7 @@ class Exceptions:
 
 class ElasticLoadBalancingClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -105,54 +105,54 @@ class ElasticLoadBalancingClient:
 
     def add_tags(self, LoadBalancerNames: List[str], Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
-        [Show boto3-stubs documentation](./client.md#add-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
+        [Show boto3-stubs documentation](./client.md#add_tags)
         """
 
     def apply_security_groups_to_load_balancer(
         self, LoadBalancerName: str, SecurityGroups: List[str]
     ) -> ApplySecurityGroupsToLoadBalancerOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
-        [Show boto3-stubs documentation](./client.md#apply-security-groups-to-load-balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
+        [Show boto3-stubs documentation](./client.md#apply_security_groups_to_load_balancer)
         """
 
     def attach_load_balancer_to_subnets(
         self, LoadBalancerName: str, Subnets: List[str]
     ) -> AttachLoadBalancerToSubnetsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
-        [Show boto3-stubs documentation](./client.md#attach-load-balancer-to-subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
+        [Show boto3-stubs documentation](./client.md#attach_load_balancer_to_subnets)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def configure_health_check(
         self, LoadBalancerName: str, HealthCheck: "HealthCheckTypeDef"
     ) -> ConfigureHealthCheckOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
-        [Show boto3-stubs documentation](./client.md#configure-health-check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
+        [Show boto3-stubs documentation](./client.md#configure_health_check)
         """
 
     def create_app_cookie_stickiness_policy(
         self, LoadBalancerName: str, PolicyName: str, CookieName: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
-        [Show boto3-stubs documentation](./client.md#create-app-cookie-stickiness-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
+        [Show boto3-stubs documentation](./client.md#create_app_cookie_stickiness_policy)
         """
 
     def create_lb_cookie_stickiness_policy(
         self, LoadBalancerName: str, PolicyName: str, CookieExpirationPeriod: int = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
-        [Show boto3-stubs documentation](./client.md#create-lb-cookie-stickiness-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
+        [Show boto3-stubs documentation](./client.md#create_lb_cookie_stickiness_policy)
         """
 
     def create_load_balancer(
@@ -166,16 +166,16 @@ class ElasticLoadBalancingClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateAccessPointOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
-        [Show boto3-stubs documentation](./client.md#create-load-balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
+        [Show boto3-stubs documentation](./client.md#create_load_balancer)
         """
 
     def create_load_balancer_listeners(
         self, LoadBalancerName: str, Listeners: List["ListenerTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
-        [Show boto3-stubs documentation](./client.md#create-load-balancer-listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
+        [Show boto3-stubs documentation](./client.md#create_load_balancer_listeners)
         """
 
     def create_load_balancer_policy(
@@ -186,114 +186,114 @@ class ElasticLoadBalancingClient:
         PolicyAttributes: List[PolicyAttributeTypeDef] = None,
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
-        [Show boto3-stubs documentation](./client.md#create-load-balancer-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
+        [Show boto3-stubs documentation](./client.md#create_load_balancer_policy)
         """
 
     def delete_load_balancer(self, LoadBalancerName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
-        [Show boto3-stubs documentation](./client.md#delete-load-balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
+        [Show boto3-stubs documentation](./client.md#delete_load_balancer)
         """
 
     def delete_load_balancer_listeners(
         self, LoadBalancerName: str, LoadBalancerPorts: List[int]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
-        [Show boto3-stubs documentation](./client.md#delete-load-balancer-listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
+        [Show boto3-stubs documentation](./client.md#delete_load_balancer_listeners)
         """
 
     def delete_load_balancer_policy(self, LoadBalancerName: str, PolicyName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
-        [Show boto3-stubs documentation](./client.md#delete-load-balancer-policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
+        [Show boto3-stubs documentation](./client.md#delete_load_balancer_policy)
         """
 
     def deregister_instances_from_load_balancer(
         self, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
     ) -> DeregisterEndPointsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
-        [Show boto3-stubs documentation](./client.md#deregister-instances-from-load-balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
+        [Show boto3-stubs documentation](./client.md#deregister_instances_from_load_balancer)
         """
 
     def describe_account_limits(
         self, Marker: str = None, PageSize: int = None
     ) -> DescribeAccountLimitsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
-        [Show boto3-stubs documentation](./client.md#describe-account-limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
+        [Show boto3-stubs documentation](./client.md#describe_account_limits)
         """
 
     def describe_instance_health(
         self, LoadBalancerName: str, Instances: List["InstanceTypeDef"] = None
     ) -> DescribeEndPointStateOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
-        [Show boto3-stubs documentation](./client.md#describe-instance-health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
+        [Show boto3-stubs documentation](./client.md#describe_instance_health)
         """
 
     def describe_load_balancer_attributes(
         self, LoadBalancerName: str
     ) -> DescribeLoadBalancerAttributesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
-        [Show boto3-stubs documentation](./client.md#describe-load-balancer-attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
+        [Show boto3-stubs documentation](./client.md#describe_load_balancer_attributes)
         """
 
     def describe_load_balancer_policies(
         self, LoadBalancerName: str = None, PolicyNames: List[str] = None
     ) -> DescribeLoadBalancerPoliciesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
-        [Show boto3-stubs documentation](./client.md#describe-load-balancer-policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
+        [Show boto3-stubs documentation](./client.md#describe_load_balancer_policies)
         """
 
     def describe_load_balancer_policy_types(
         self, PolicyTypeNames: List[str] = None
     ) -> DescribeLoadBalancerPolicyTypesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
-        [Show boto3-stubs documentation](./client.md#describe-load-balancer-policy-types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
+        [Show boto3-stubs documentation](./client.md#describe_load_balancer_policy_types)
         """
 
     def describe_load_balancers(
         self, LoadBalancerNames: List[str] = None, Marker: str = None, PageSize: int = None
     ) -> DescribeAccessPointsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
-        [Show boto3-stubs documentation](./client.md#describe-load-balancers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
+        [Show boto3-stubs documentation](./client.md#describe_load_balancers)
         """
 
     def describe_tags(self, LoadBalancerNames: List[str]) -> DescribeTagsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
-        [Show boto3-stubs documentation](./client.md#describe-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
+        [Show boto3-stubs documentation](./client.md#describe_tags)
         """
 
     def detach_load_balancer_from_subnets(
         self, LoadBalancerName: str, Subnets: List[str]
     ) -> DetachLoadBalancerFromSubnetsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
-        [Show boto3-stubs documentation](./client.md#detach-load-balancer-from-subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
+        [Show boto3-stubs documentation](./client.md#detach_load_balancer_from_subnets)
         """
 
     def disable_availability_zones_for_load_balancer(
         self, LoadBalancerName: str, AvailabilityZones: List[str]
     ) -> RemoveAvailabilityZonesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
-        [Show boto3-stubs documentation](./client.md#disable-availability-zones-for-load-balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
+        [Show boto3-stubs documentation](./client.md#disable_availability_zones_for_load_balancer)
         """
 
     def enable_availability_zones_for_load_balancer(
         self, LoadBalancerName: str, AvailabilityZones: List[str]
     ) -> AddAvailabilityZonesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
-        [Show boto3-stubs documentation](./client.md#enable-availability-zones-for-load-balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
+        [Show boto3-stubs documentation](./client.md#enable_availability_zones_for_load_balancer)
         """
 
     def generate_presigned_url(
@@ -304,56 +304,56 @@ class ElasticLoadBalancingClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def modify_load_balancer_attributes(
         self, LoadBalancerName: str, LoadBalancerAttributes: "LoadBalancerAttributesTypeDef"
     ) -> ModifyLoadBalancerAttributesOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
-        [Show boto3-stubs documentation](./client.md#modify-load-balancer-attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
+        [Show boto3-stubs documentation](./client.md#modify_load_balancer_attributes)
         """
 
     def register_instances_with_load_balancer(
         self, LoadBalancerName: str, Instances: List["InstanceTypeDef"]
     ) -> RegisterEndPointsOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
-        [Show boto3-stubs documentation](./client.md#register-instances-with-load-balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
+        [Show boto3-stubs documentation](./client.md#register_instances_with_load_balancer)
         """
 
     def remove_tags(
         self, LoadBalancerNames: List[str], Tags: List[TagKeyOnlyTypeDef]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
-        [Show boto3-stubs documentation](./client.md#remove-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
+        [Show boto3-stubs documentation](./client.md#remove_tags)
         """
 
     def set_load_balancer_listener_ssl_certificate(
         self, LoadBalancerName: str, LoadBalancerPort: int, SSLCertificateId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
-        [Show boto3-stubs documentation](./client.md#set-load-balancer-listener-ssl-certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
+        [Show boto3-stubs documentation](./client.md#set_load_balancer_listener_ssl_certificate)
         """
 
     def set_load_balancer_policies_for_backend_server(
         self, LoadBalancerName: str, InstancePort: int, PolicyNames: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
-        [Show boto3-stubs documentation](./client.md#set-load-balancer-policies-for-backend-server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
+        [Show boto3-stubs documentation](./client.md#set_load_balancer_policies_for_backend_server)
         """
 
     def set_load_balancer_policies_of_listener(
         self, LoadBalancerName: str, LoadBalancerPort: int, PolicyNames: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
-        [Show boto3-stubs documentation](./client.md#set-load-balancer-policies-of-listener)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
+        [Show boto3-stubs documentation](./client.md#set_load_balancer_policies_of_listener)
         """
 
     @overload
@@ -361,7 +361,7 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_account_limits"]
     ) -> DescribeAccountLimitsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)[Show boto3-stubs documentation](./paginators.md#describeaccountlimitspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)[Show boto3-stubs documentation](./paginators.md#describeaccountlimitspaginator)
         """
 
     @overload
@@ -369,7 +369,7 @@ class ElasticLoadBalancingClient:
         self, operation_name: Literal["describe_load_balancers"]
     ) -> DescribeLoadBalancersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)[Show boto3-stubs documentation](./paginators.md#describeloadbalancerspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)[Show boto3-stubs documentation](./paginators.md#describeloadbalancerspaginator)
         """
 
     @overload
@@ -377,7 +377,7 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["any_instance_in_service"]
     ) -> AnyInstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Waiter.any_instance_in_service)[Show boto3-stubs documentation](./waiters.md#anyinstanceinservicewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Waiter.any_instance_in_service)[Show boto3-stubs documentation](./waiters.md#anyinstanceinservicewaiter)
         """
 
     @overload
@@ -385,11 +385,11 @@ class ElasticLoadBalancingClient:
         self, waiter_name: Literal["instance_deregistered"]
     ) -> InstanceDeregisteredWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_deregistered)[Show boto3-stubs documentation](./waiters.md#instancederegisteredwaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_deregistered)[Show boto3-stubs documentation](./waiters.md#instancederegisteredwaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["instance_in_service"]) -> InstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_in_service)[Show boto3-stubs documentation](./waiters.md#instanceinservicewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/elb.html#ElasticLoadBalancing.Waiter.instance_in_service)[Show boto3-stubs documentation](./waiters.md#instanceinservicewaiter)
         """
